==> jaguar_jwt-0.1.1.tar.gz: test/decoding/decoding.dart <==
library test.decoding;

import 'package:test/test.dart';
import 'package:jaguar_jwt/jaguar_jwt.dart';
import 'package:dart_jwt/dart_jwt.dart';

main() {
  group('Decoding', () {
    test('Nopayload', () {
      String encoded =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwiaXNzIjoidGVqYSIsImF1ZCI6WyJhZG1pbiIsInN0dWRlbnRzIl19.SthPOKxM50xcrdVzR7On1-98OMzd0LWQbaFpRheUCCY';
      final decoder = new JwtAuthorizationContext(
          new JwaSymmetricKeySignatureContext('secret'), 'teja');
      JsonWebToken tok = decoder.decodeToken(encoded);
      JaguarJwtClaimSet claimSet = tok.claimSet;
      expect(claimSet.issuer, equals('teja'));
      expect(claimSet.audience, equals(["admin", "students"]));
      expect(claimSet.payload, isNull);
      expect(claimSet.subject, "1234567890");
    });

    test('With payload', () {
      String encoded =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwiaXNzIjoidGVqYSIsImF1ZCI6WyJhZG1pbiIsInN0dWRlbnRzIl0sInBheWxvYWQiOnsiayI6InYifX0.pVllp9aTQ-kM2hEjQBGW8slJ_qypb0TgFOKXfft3Erg';
      final decoder = new JwtAuthorizationContext(
          new JwaSymmetricKeySignatureContext('secret'), 'teja');
      JsonWebToken tok = decoder.decodeToken(encoded);
      JaguarJwtClaimSet claimSet = tok.claimSet;
      expect(claimSet.issuer, equals('teja'));
      expect(claimSet.audience, equals(["admin", "students"]));
      expect(claimSet.payload, equals({"k": "v"}));
      expect(claimSet.subject, "1234567890");
    });
  });
}

==> jaguar_jwt-0.2.0.tar.gz: test/decoding/decoding.dart <==
library test.decoding;

import 'package:test/test.dart';
import 'package:jaguar_jwt/jaguar_jwt.dart';
import 'package:dart_jwt/dart_jwt.dart';

main() {
  group('Decoding', () {
    test('Nopayload', () {
      String encoded =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwiaXNzIjoidGVqYSIsImF1ZCI6WyJhZG1pbiIsInN0dWRlbnRzIl19.SthPOKxM50xcrdVzR7On1-98OMzd0LWQbaFpRheUCCY';
      final decoder = new AuthorizationConf(
          new JwaSymmetricKeySignatureContext('secret'), 'teja');
      JsonWebToken tok = decoder.decodeToken(encoded);
      ClaimSet claimSet = tok.claimSet;
      expect(claimSet.issuer, equals('teja'));
      expect(claimSet.audience, equals(["admin", "students"]));
      expect(claimSet.payload, isNull);
      expect(claimSet.subject, "1234567890");
    });

    test('With payload', () {
      String encoded =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwiaXNzIjoidGVqYSIsImF1ZCI6WyJhZG1pbiIsInN0dWRlbnRzIl0sInBheWxvYWQiOnsiayI6InYifX0.pVllp9aTQ-kM2hEjQBGW8slJ_qypb0TgFOKXfft3Erg';
      final decoder = new AuthorizationConf(
          new JwaSymmetricKeySignatureContext('secret'), 'teja');
      JsonWebToken tok = decoder.decodeToken(encoded);
      ClaimSet claimSet = tok.claimSet;
      expect(claimSet.issuer, equals('teja'));
      expect(claimSet.audience, equals(["admin", "students"]));
      expect(claimSet.payload, equals({"k": "v"}));
      expect(claimSet.subject, "1234567890");
    });
  });
}
